$set 3 #Configmenu

$ #ConfigOptions
# Options de configuration
$ #FocusModel
# Mode d'attribution du clavier
$ #WindowPlacement
# Disposition des fentres
$ #ImageDithering
# Lissage des images
$ #OpaqueMove
# Dplacement opaque des fentres
$ #FullMax
# Maximisation complte
$ #FocusNew
# Attribuer le clavier  la nouvelle fentre
$ #FocusLast
# Attribuer le clavier en changeant d'espace de travail
$ #DisableBindings
# Dsactiver les modificateurs avec Vrouillage Dfilement
$ #ClickToFocus
# Cliquer pour obtenir le clavier
$ #SloppyFocus
# Attribution du clavier souple
$ #AutoRaise
# Premier plan automatique
$ #ClickRaise
# Cliquer pour mettre au premier plan
$ #SmartRows
# Disposition fute (Lignes)
$ #SmartCols
# Disposition fute (Colonnes)
$ #Cascade
# Disposition en cascade
$ #LeftRight
# De gauche  droite
$ #RightLeft
# De droite  gauche
$ #TopBottom
# De haut en bas
$ #BottomTop
# De bas en haut
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
